# ArchiverR_Client



## Installation
Pour pouvoir installer Archiverr_Client depuis le code source. Il vous faudra une version python versi 3.11.9 afin d'être sur de la comptabilité.

Ensuite placez vous dans un terminal à la racine du dossier Archiverr_Client et lancez la commande suivante:
```bash
pip install -r requirements.txt
```
Cette commande va installer toutes les dépendances nécessaires pour le bon fonctionnement du programme.
Puis, pour lancer le programme, il vous suffit de lancer la commande suivante:
```bash
python archiverr
```
La liste des commandes s'affichera et vous pourrez commencer à utiliser le programme.